@@ -204,6 +204,7 @@ def categorical_ttt_dist(train=None, test=None, val=None, features=[], target='t
         
         train_group = train.groupby(feature).agg({feature:'count', target:agg_func})
         train_group.columns = [feature+'_count', target]
+        train_group[feature+'_count'] /= train.shape[0]
         for value in diff_test:
             train_group.loc[value, :] = [np.nan,np.nan]
         train_group.sort_index(inplace=True)
@@ -228,41 +229,45 @@ def categorical_ttt_dist(train=None, test=None, val=None, features=[], target='t
         row_dict = {}
         row_dict['feature'] = feature
         row_dict['train_nunique'] = train[feature].nunique()
+        max_rate = max(train.shape[0], _return_shape(test), _return_shape(val))
 
         if test is not None: 
             diff_test_stats = set(diff_test) - set(test_counts.index)            
             test_group = test.groupby(feature).agg({feature:'count', target:agg_func})
             test_group.columns = [feature+'_count', target]
+            test_group[feature+'_count'] /= test.shape[0]
             for value in diff_test_stats:
                 test_group.loc[value, :] = [np.nan, np.nan]
             test_group.sort_index(inplace=True)
 
             row_dict['test_nunique'] = test[feature].nunique()
-            row_dict['train_test_rmse'] = np.sqrt(np.sum((train_group[feature+'_count'] - test_group[feature+'_count'])**2))
+            row_dict['train_test_rmse'] = np.sqrt(np.sum((train_group[feature+'_count'] - test_group[feature+'_count'])**2))*max_rate
             row_dict['train_test_same_unique'] = set(train[feature].unique()) == set(test[feature].unique())
 
             if val is not None: 
                 diff_val_stats = set(diff_test) - set(val_counts.index)            
                 val_group = val.groupby(feature).agg({feature:'count', target:agg_func})
                 val_group.columns = [feature+'_count', target]
+                val_group[feature+'_count'] /= val.shape[0]
                 for value in diff_val_stats:
                     val_group.loc[value, :] = [np.nan, np.nan]
                 val_group.sort_index(inplace=True)
 
                 row_dict['val_nunique'] = val[feature].nunique()
-                row_dict['val_test_rmse'] = np.sqrt(np.sum((test_group[feature+'_count'] - val_group[feature+'_count'])**2))
+                row_dict['val_test_rmse'] = np.sqrt(np.sum((test_group[feature+'_count'] - val_group[feature+'_count'])**2))*max_rate
                 row_dict['val_test_same_unique'] = set(val[feature].unique()) == set(test[feature].unique())
         
         if val is not None: 
             diff_val_stats = set(diff_test) - set(val_counts.index)            
             val_group = val.groupby(feature).agg({feature:'count', target:agg_func})
             val_group.columns = [feature+'_count', target]
+            val_group[feature+'_count'] /= val.shape[0]
             for value in diff_val_stats:
                 val_group.loc[value, :] = [np.nan, np.nan]
             val_group.sort_index(inplace=True)
 
             row_dict['val_nunique'] = val[feature].nunique()
-            row_dict['train_val_rmse'] = np.sqrt(np.sum((train_group[feature+'_count'] - val_group[feature+'_count'])**2))
+            row_dict['train_val_rmse'] = np.sqrt(np.sum((train_group[feature+'_count'] - val_group[feature+'_count'])**2))*max_rate
             row_dict['train_val_target_rmse'] = np.sqrt(np.sum((train_group[target] - val_group[target])**2))
             row_dict['train_val_same_unique'] = set(train[feature].unique()) == set(val[feature].unique())
         df_stats = df_stats.append(row_dict, ignore_index=True)
@@ -272,8 +277,8 @@ def categorical_ttt_dist(train=None, test=None, val=None, features=[], target='t
     fig.tight_layout()
     plt.show()
     df_stats.dropna(axis=1, inplace=True)
-    if val is not None:  df_stats.sort_values('train_val_rmse', inplace=True)
     if test is not None:  df_stats.sort_values('train_test_rmse', inplace=True)
+    if val is not None:  df_stats.sort_values('train_val_target_rmse', inplace=True)
     return df_stats
 
 
@@ -291,6 +296,13 @@ def _return_max(data, feature):
         return -999999
 
 
+def _return_shape(data):
+    try:
+        return data.shape[0]
+    except:
+        return 0
+
+
 def _find_trend_changes(data):
     data_diff = data.diff()
     data_diff = data_diff > 0
